/* 
 * DinX access library routines
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * The Original Code is DinX.
 * 
 * The Initial Developer of the Original Code is Ben Williamson.
 * Portions created by Ben Williamson are Copyright (C) 1999
 * Ben Williamson. All Rights Reserved.
 * 
 * Contributor(s):	Ben Williamson <benw@pobox.com>
 * 
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU General Public license (the  "[GPL] License"), in which case the
 * provisions of [GPL] License are applicable instead of those
 * above.  If you wish to allow use of your version of this file only
 * under the terms of the [GPL] License and not to allow others to use
 * your version of this file under the MPL, indicate your decision by
 * deleting  the provisions above and replace  them with the notice and
 * other provisions required by the [GPL] License.  If you do not delete
 * the provisions above, a recipient may use your version of this file
 * under either the MPL or the [GPL] License.
 */

#ifndef _DINX_ACCESS_H_
#define _DINX_ACCESS_H_

#include <linux/dinx.h>

#ifdef __cplusplus
extern "C" {
#endif

union dmessage;

struct devent_ops {
	void	(*tree_info)(void *data, const drect *bounds, int bpp);
	void	(*message)(void *data, const union dmessage *message);
	void	(*redraw)(void *data, const struct drect *rect, int more);
	void	(*mouse)(void *data, const struct dvect *pos, int buttons);
	void	(*key)(void *data, int key);
};

extern int dinx_open(const char *device);
extern int dinx_close(int fd);

/* helper for dispatching events */
extern int dinx_read_event(int fd, struct devent_ops *ops, void *data);

/* commands handled by the kernel */
extern int dinx_message(int fd, const union dmessage *message);
extern int dinx_simple_message(int fd, int type);
extern int dinx_fill_rect(int fd, const drect *rect, unsigned long col);
extern int dinx_move_rect(int fd, const drect *rect, const dvect *moveby);
extern int dinx_copy_rect(int fd, const drect *dest, const dvect *base,
	const void *src, int src_width, int src_bpp, const unsigned long *pal);

/* messages handled by the server */
extern int dinx_req_bounds(int fd, const drect *bounds, const dvect *origin);
extern int dinx_req_map(int fd);
extern int dinx_req_unmap(int fd);
extern int dinx_req_raise(int fd);
extern int dinx_req_lower(int fd);

/* server commands to the kernel */
extern int dinx_message_to(int fd, const union dmessage *message,
				unsigned long win);
extern int dinx_set_bounds(int fd, unsigned int win,
				const drect *bounds, const dvect *origin);
extern int dinx_map(int fd, unsigned int win);
extern int dinx_unmap(int fd, unsigned int win);
extern int dinx_raise(int fd, unsigned int win);
extern int dinx_lower(int fd, unsigned int win);
extern int dinx_simple_command(int fd, int type);
extern int dinx_select_fb(int fd, int framebuffer);

#ifdef __cplusplus
}
#endif

#endif	/* _DINX_ACCESS_H_ */

